import { Component, OnInit, Input } from '@angular/core';
import { ActivatedRoute } from '@angular/router';
import { Location } from '@angular/common';

import { Hero } from '../hero';
import { HeroService } from '../hero.service';
import { MessageService } from '../message.service';

@Component({
  selector: 'app-hero-detail',
  templateUrl: './hero-detail.component.html',
  styleUrls: ['./hero-detail.component.css']
})
export class HeroDetailComponent implements OnInit {

  @Input() hero: Hero;
  
  constructor(private route: ActivatedRoute, private heroService: HeroService, private location: Location, private messageService: MessageService) { }

  ngOnInit(): void {
    this.getHero();
  }

  async getHero(): Promise<void> {
    try {
      const id = +this.route.snapshot.paramMap.get('id');
      this.hero = await this.heroService.getHero(id)
    } catch (err) {
      this.messageService.add(JSON.stringify(err, undefined, 4))
    }
  }

  goBack(): void {
    this.location.back();
  }

  async save(): Promise<void> {
    try {
      await this.heroService.updateHero(this.hero)
      this.goBack()
    } catch (err) {
      this.messageService.add(JSON.stringify(err, undefined, 4))
    }
  }
}
